pub fn mock_column(column: &FixedColumn, rng: &mut ThreadRng) -> StringExpand description
Create a string with mocked data based on the FixedColumn datatype.
pub fn mock_column(column: &FixedColumn, rng: &mut ThreadRng) -> StringCreate a string with mocked data based on the FixedColumn datatype.