Module mocker

Structs

FixedLengthFileMocker
The mocker struct for fixed-length files (.flf).
FixedLengthFileMockerBuilder
A helper struct for building an instance of a FixedLengthFileMocker struct.

Statics

MIN_NUM_ROWS_FOR_MULTITHREADING
If the user only wants to generate a small amount of mocked .flf rows then multithreading is not a stuiable choice and probably only introduces extra overhead. This variable specifies the minimum number of rows to be mocked to allow enabling multithreading.

Traits

Mocker
Unified trait for all types of file mockers.

Type Aliases

MockerRef