pub struct FixedLengthFileMocker { /* private fields */ }Expand description
The mocker struct for fixed-length files (.flf).
Implementations
Sourceimpl FixedLengthFileMocker
impl FixedLengthFileMocker
Sourcepub fn builder() -> FixedLengthFileMockerBuilder
pub fn builder() -> FixedLengthFileMockerBuilder
Create a new instance of a FixedLengthFileMockerBuilder with default values.
Sourcepub fn try_mock(&mut self) -> Result<()>
pub fn try_mock(&mut self) -> Result<()>
Try and generate mocked data based on the provided FixedSchema.
This function either runs in single-threaded mode or in multithreaded mode depending on:
- the number of requested mocked rows to generate,
- and the number of avilable threads on the host system.
Errors
This function will propagate any errors created in any of the mocking modes, see any
of the functions try_mock_multithreaded or try_mock_single_threaded for specifics.